==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebActivePaneEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebActivePaneEventArgsDetailDescription } from "./WebActivePaneEventArgsDetailDescription";
/**
 * @hidden
 */
var WebActivePaneEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebActivePaneEventArgsDetailDescriptionMetadata, _super);
    function WebActivePaneEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActivePaneEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebActivePaneEventArgsDetailDescriptionMetadata.a == null) {
            WebActivePaneEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActivePaneEventArgsDetailDescriptionMetadata.c(WebActivePaneEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebActivePaneEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebActivePaneEventArgsDetailDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebActivePaneEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActivePaneEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__skipSuffix", "Boolean");
        a.item("NewPane", "ExportedType:WebContentPane");
        a.item("OldPane", "ExportedType:WebContentPane");
    };
    WebActivePaneEventArgsDetailDescriptionMetadata.d = function (a) {
        WebActivePaneEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebActivePaneEventArgsDetail", function () { return new WebActivePaneEventArgsDetailDescription(); });
        a.ab("WebActivePaneEventArgsDetail", WebActivePaneEventArgsDetailDescriptionMetadata.a);
    };
    WebActivePaneEventArgsDetailDescriptionMetadata.$t = markType(WebActivePaneEventArgsDetailDescriptionMetadata, 'WebActivePaneEventArgsDetailDescriptionMetadata');
    WebActivePaneEventArgsDetailDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDetailDescriptionMetadata;
}(Base));
export { WebActivePaneEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebActivePaneEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebActivePaneEventArgsDetailDescription } from "./WebActivePaneEventArgsDetailDescription";
/**
 * @hidden
 */
var WebActivePaneEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebActivePaneEventArgsDetailDescriptionMetadata, _super);
    function WebActivePaneEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebActivePaneEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebActivePaneEventArgsDetailDescriptionMetadata.a == null) {
            WebActivePaneEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebActivePaneEventArgsDetailDescriptionMetadata.c(WebActivePaneEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebActivePaneEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebActivePaneEventArgsDetailDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebActivePaneEventArgsDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ActivePaneEventArgsDetail");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("NewPane", "ExportedType:WebContentPane");
        a.item("OldPane", "ExportedType:WebContentPane");
    };
    WebActivePaneEventArgsDetailDescriptionMetadata.d = function (a) {
        WebActivePaneEventArgsDetailDescriptionMetadata.b(a);
        a.ae("WebActivePaneEventArgsDetail", function () { return new WebActivePaneEventArgsDetailDescription(); });
        a.ad("WebActivePaneEventArgsDetail", WebActivePaneEventArgsDetailDescriptionMetadata.a);
    };
    WebActivePaneEventArgsDetailDescriptionMetadata.$t = markType(WebActivePaneEventArgsDetailDescriptionMetadata, 'WebActivePaneEventArgsDetailDescriptionMetadata');
    WebActivePaneEventArgsDetailDescriptionMetadata.a = null;
    return WebActivePaneEventArgsDetailDescriptionMetadata;
}(Base));
export { WebActivePaneEventArgsDetailDescriptionMetadata };
